@@ -288,7 +288,7 @@ dzl_recursive_file_monitor_changed (DzlRecursiveFileMonitor *self,
     }
   else if (event == G_FILE_MONITOR_EVENT_CREATED)
     {
-      if (g_file_query_file_type (file, 0, NULL) == G_FILE_TYPE_DIRECTORY)
+      if (g_file_query_file_type (file, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL) == G_FILE_TYPE_DIRECTORY)
         {
           g_autoptr(GPtrArray) dirs = NULL;
 
@@ -465,6 +465,9 @@ dzl_recursive_file_monitor_dispose (GObject *object)
   g_cancellable_cancel (self->cancellable);
   dzl_recursive_file_monitor_set_ignore_func (self, NULL, NULL, NULL);
 
+  g_hash_table_remove_all (self->files_by_monitor);
+  g_hash_table_remove_all (self->monitors_by_file);
+
   G_OBJECT_CLASS (dzl_recursive_file_monitor_parent_class)->dispose (object);
 }
 
@@ -476,8 +479,8 @@ dzl_recursive_file_monitor_finalize (GObject *object)
   g_clear_object (&self->root);
   g_clear_object (&self->cancellable);
 
-  dzl_clear_pointer (&self->files_by_monitor, g_hash_table_unref);
-  dzl_clear_pointer (&self->monitors_by_file, g_hash_table_unref);
+  g_clear_pointer (&self->files_by_monitor, g_hash_table_unref);
+  g_clear_pointer (&self->monitors_by_file, g_hash_table_unref);
 
   G_OBJECT_CLASS (dzl_recursive_file_monitor_parent_class)->finalize (object);
 }
