@@ -1060,6 +1060,8 @@ dzl_dock_bin_child_size_allocate (DzlDockBin      *self,
         gdk_window_move_resize (child->handle,
                                 handle_alloc.x, handle_alloc.y,
                                 handle_alloc.width, handle_alloc.height);
+      else if (child->handle)
+        gdk_window_hide (child->handle);
 
       gtk_widget_size_allocate (child->widget, &child_alloc);
     }
@@ -1736,6 +1738,52 @@ dzl_dock_bin_init_child (DzlDockBin          *self,
   child->pre_anim_pinned = TRUE;
 }
 
+static gboolean
+dzl_dock_bin_draw (GtkWidget *widget,
+                   cairo_t   *cr)
+{
+  DzlDockBin *self = (DzlDockBin *)widget;
+  DzlDockBinPrivate *priv = dzl_dock_bin_get_instance_private (self);
+  const guint draw_order[] = { DZL_DOCK_BIN_CHILD_CENTER,
+                               DZL_DOCK_BIN_CHILD_LEFT,
+                               DZL_DOCK_BIN_CHILD_RIGHT,
+                               DZL_DOCK_BIN_CHILD_TOP,
+                               DZL_DOCK_BIN_CHILD_BOTTOM };
+
+  g_assert (DZL_IS_DOCK_BIN (self));
+  g_assert (cr != NULL);
+
+  /* All pinned children, in proper draw order */
+  for (guint i = 0; i < G_N_ELEMENTS (draw_order); i++)
+    {
+      const DzlDockBinChild *child = &priv->children[draw_order[i]];
+
+      if (!child->pinned ||
+          !GTK_IS_WIDGET (child->widget) ||
+          !gtk_widget_get_visible (child->widget) ||
+          !gtk_widget_get_child_visible (child->widget))
+        continue;
+
+      gtk_container_propagate_draw (GTK_CONTAINER (self), child->widget, cr);
+    }
+
+  /* All unpinned children, in proper draw order */
+  for (guint i = 1; i < G_N_ELEMENTS (draw_order); i++)
+    {
+      const DzlDockBinChild *child = &priv->children[draw_order[i]];
+
+      if (child->pinned ||
+          !GTK_IS_WIDGET (child->widget) ||
+          !gtk_widget_get_visible (child->widget) ||
+          !gtk_widget_get_child_visible (child->widget))
+        continue;
+
+      gtk_container_propagate_draw (GTK_CONTAINER (self), child->widget, cr);
+    }
+
+  return FALSE;
+}
+
 static void
 dzl_dock_bin_destroy (GtkWidget *widget)
 {
@@ -1884,6 +1932,7 @@ dzl_dock_bin_class_init (DzlDockBinClass *klass)
   widget_class->destroy = dzl_dock_bin_destroy;
   widget_class->drag_leave = dzl_dock_bin_drag_leave;
   widget_class->drag_motion = dzl_dock_bin_drag_motion;
+  widget_class->draw = dzl_dock_bin_draw;
   widget_class->focus = dzl_dock_bin_focus;
   widget_class->get_preferred_height = dzl_dock_bin_get_preferred_height;
   widget_class->get_preferred_width = dzl_dock_bin_get_preferred_width;
