@@ -389,6 +389,8 @@ dzl_shortcut_controller_set_widget (DzlShortcutController *self,
           dzl_shortcut_controller_connect (self);
         }
 
+      g_assert (widget == priv->widget);
+
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_WIDGET]);
     }
 }
@@ -438,12 +440,7 @@ dzl_shortcut_controller_finalize (GObject *object)
   DzlShortcutController *self = (DzlShortcutController *)object;
   DzlShortcutControllerPrivate *priv = dzl_shortcut_controller_get_instance_private (self);
 
-  if (priv->widget != NULL)
-    {
-      g_object_remove_weak_pointer (G_OBJECT (priv->widget), (gpointer *)&priv->widget);
-      priv->widget = NULL;
-    }
-
+  dzl_clear_weak_pointer (&priv->widget);
   g_clear_pointer (&priv->commands, g_hash_table_unref);
   g_clear_pointer (&priv->commands_table, dzl_shortcut_chord_table_free);
   g_clear_object (&priv->root);
@@ -660,6 +657,8 @@ dzl_shortcut_controller_find (GtkWidget *widget)
       controller = g_object_get_qdata (G_OBJECT (widget), controller_quark);
     }
 
+  g_return_val_if_fail (DZL_IS_SHORTCUT_CONTROLLER (controller), NULL);
+
   return controller;
 }
 
@@ -1231,3 +1230,58 @@ _dzl_shortcut_controller_clear (DzlShortcutController *self)
   g_clear_pointer (&priv->current_chord, dzl_shortcut_chord_free);
   g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_CURRENT_CHORD]);
 }
+
+/**
+ * dzl_shortcut_controller_get_widget:
+ * @self: a #DzlShortcutController
+ *
+ * Returns: (transfer none): the widget for the controller
+ *
+ * Since: 3.34
+ */
+GtkWidget *
+dzl_shortcut_controller_get_widget (DzlShortcutController *self)
+{
+  DzlShortcutControllerPrivate *priv = dzl_shortcut_controller_get_instance_private (self);
+
+  g_return_val_if_fail (DZL_IS_SHORTCUT_CONTROLLER (self), NULL);
+
+  return priv->widget;
+}
+
+void
+dzl_shortcut_controller_remove_accel (DzlShortcutController *self,
+                                      const gchar           *accel,
+                                      DzlShortcutPhase       phase)
+{
+  DzlShortcutControllerPrivate *priv = dzl_shortcut_controller_get_instance_private (self);
+  g_autoptr(DzlShortcutChord) chord = NULL;
+
+  g_return_if_fail (DZL_IS_SHORTCUT_CONTROLLER (self));
+  g_return_if_fail (accel != NULL);
+
+  chord = dzl_shortcut_chord_new_from_string (accel);
+
+  if (chord != NULL)
+    {
+      DzlShortcutContext *context;
+      DzlShortcutManager *manager;
+      DzlShortcutTheme *theme;
+
+      /* Add the chord to our chord table for lookups */
+      if (priv->commands_table != NULL)
+        dzl_shortcut_chord_table_remove (priv->commands_table, chord);
+
+      /* Set the value in the theme so it can have overrides by users */
+      manager = dzl_shortcut_controller_get_manager (self);
+      theme = _dzl_shortcut_manager_get_internal_theme (manager);
+      dzl_shortcut_theme_set_chord_for_command (theme, NULL, chord, 0);
+
+      if (priv->widget != NULL)
+        {
+          context = _dzl_shortcut_theme_find_default_context_with_phase (theme, priv->widget, phase);
+          if (context && _dzl_shortcut_context_contains (context, chord))
+            dzl_shortcut_context_remove (context, accel);
+        }
+    }
+}
