@@ -52,7 +52,11 @@ G_DEFINE_BOXED_TYPE (DzlCounterArena, dzl_counter_arena, dzl_counter_arena_ref,
 #define CELLS_PER_GROUP(ncpu)                             \
   (((sizeof (CounterInfo) * COUNTERS_PER_GROUP) +         \
     (sizeof(DzlCounterValue) * (ncpu))) / DATA_CELL_SIZE)
-#define DZL_MEMORY_BARRIER __sync_synchronize()
+#ifdef DZL_COUNTER_REQUIRES_ATOMIC
+#define DZL_MEMORY_BARRIER G_STMT_START { __sync_synchronize(); } G_STMT_END
+#else
+#define DZL_MEMORY_BARRIER G_STMT_START {} G_STMT_END
+#endif
 
 typedef struct
 {
@@ -423,7 +427,7 @@ _dzl_counter_arena_destroy (DzlCounterArena *arena)
     g_free (arena->cells);
 #endif
 
-  dzl_clear_pointer (&arena->counters, g_list_free);
+  g_clear_pointer (&arena->counters, g_list_free);
 
   arena->cells = NULL;
 
