@@ -117,6 +117,10 @@ test_index_builder_basic (void)
   g_assert (r);
 
   g_object_unref (file);
+
+  while (g_main_context_pending (NULL))
+    g_main_context_iteration (NULL, TRUE);
+
   g_main_loop_unref (main_loop);
 }
 
